@@ -5,5 +5,7 @@ A Python package that provides structure for networks of interconnected nodes
 using the DOT language for representation.
 '''
 
-from .core import *
-__version__ = "0.4.4"
+from .classes import *
+from .functions import *
+
+__version__ = "0.4.5"
